# Skript pro fitovani parametru modelu prechodoveho jevu v RLC obvodu pri podkritickem
# tlumeni na prislusna data. 
# Verze 2023-10-02, viz rovnice (6.41) ve skriptech (k aktualnimu datu)
# se substituci -omega_d*t0=phi
# Skript volany z programu Gnuplot
# Uziti: load 'fit_podkriticke.gp'
#
# Pouziva vstupni soubor fit_podkriticke_start.par se vstupnimi
# parametry  modelove funkce. Ty musi byt na pocatku vhodne zvoleny - 
# viz funkce model_podkriticke.gp. 
# Pozn. Je mozne, ze bude treba pouzit whodny vystupni terminal
# viz prik. radek set terminal qt ...
# qt muze byt treba nahradit za wxt nebo windows. Dostupne terminaly
# jsou vypsany po zadani prikazu
# print GPVAL_TERMINALS

# Inicializace, upravte dle potreby:
# soubor s modelovymi parametry
filenam_initpar='fit_podkriticke_start.par'
# soubor s daty z osciloskopu pro podkriticke tlumeni
filenam_data='podkriticke.csv'
# modelova funkce
f(x) = UC5*exp(-(alpha/1.0e-2)*(x-t0/1.0e2))*cos((omega_d/1.0e-3)*(x-t0/1.0e2))+Uf



# Provedeni fitu a vlastni vykresleni dat a modelu
set datafile separator ','
load filenam_initpar
set xrange [(t0/1.0e2):*]
set terminal qt 0 font "Sans,12" linewidth 2
set output
set xlabel "t (s)"
set ylabel "U_2 (V)"
set samples 2000
set grid
set fit logfile 'fit_podkriticke.log'
fit [0.0238028:*] f(x) filenam_data every ::3 u 1:3 via filenam_initpar

plot filenam_data every ::3 u 1:3 with points ps .3 title 'data', f(x) \
  with lines title 'fit'

#ulozeni obrazku do souboru
set terminal png size 800,600 enhanced font "Helvetica" fontscale 2 \
  linewidth 2
set output 'fit_podkriticke.png'
set xtics .004
set ytics 2
replot 
set terminal qt 0 font "Sans,12" linewidth 2
set output
set xtics autofreq
set ytics autofreq

set fit logfile 'fit.log'
